==> submarine-dist-0.6.0-src.tar.gz: submarine-dist-0.6.0-src/website/docs/community/README.md <==
---
title: Apache Submarine Community
---

<!--
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

Welcome to the Apache Submarine Community! The main objective is to help members of the Submarine community who share similar interests to learn from and collaborate with each other.

Your journey of becoming a contributor and committer starts from here: improving docs, improving code, giving talks, organizing meetups, etc.

## Communicating

You can reach out to the community members via any one of the following ways:

- Slack Developer: [https://join.slack.com/t/the-asf/shared_invite/zt-vlfbf7ch-HkbNHiU_uDlcH_RvaHv9gQ](https://join.slack.com/t/the-asf/shared_invite/zt-vlfbf7ch-HkbNHiU_uDlcH_RvaHv9gQ)

- Zoom: [https://cloudera.zoom.us/j/880548968](https://cloudera.zoom.us/j/880548968)

- Sync Up: [https://docs.google.com/document/d/16pUO3TP4SxSeLduG817GhVAjtiph9HYpRHo_JgduDvw/edit](https://docs.google.com/document/d/16pUO3TP4SxSeLduG817GhVAjtiph9HYpRHo_JgduDvw/edit)

## Your First Contribution

You can start by finding an existing issue with the [https://issues.apache.org/jira/projects/SUBMARINE/issues/SUBMARINE?filter=allopenissues](https://issues.apache.org/jira/projects/SUBMARINE/issues/SUBMARINE?filter=allopenissues) label. These issues are well suited for new contributors.

If a PR (Pull Request) submitted to the [Submarine Github](https://github.com/apache/submarine) projects by you is approved and merged, then you become a Submarine Contributor.

If you want to work on a new idea of relatively small scope:

1. Submit an issue describing your proposed change to the repo in question.

2. The repo owners will respond to your issue promptly.

3. Submit a [pull request of Submarine](https://github.com/apache/submarine) containing a tested change.

Contributions are welcomed and greatly appreciated. See [CONTRIBUTING](contributing) for details on submitting patches and the contribution workflow.

## How Do I Become a Committer?

First of all, you need to get involved and be a Contributor.

Based on your track-record as a contributor, Per Apache code, PMCs vote on committership, may invite you to be a committer (after we've called a vote). When that happens, if you accept, the following process kicks into place...

Note that becoming a committer is not just about submitting some patches; it‘s also about helping out on the development and user [Slack User](https://the-asf.slack.com/submarine-user/), helping with documentation and the issues.

## How to commit

See [How to commit](HowToCommit.md) for helper doc for Submarine committers.

## Communication

Communication within the Submarine community abides by [Apache’s Code of Conduct](https://www.apache.org/foundation/policies/conduct.html).

## Mailing lists

Get help using Apache Submarine or contribute to the project on our mailing lists:

- [Users](https://lists.apache.org/list.html?users@submarine.apache.org) : [subscribe](mailto:users-subscribe@submarine.apache.org), [unsubscribe](mailto:users-unsubscribe@submarine.apache.org), [archives](https://lists.apache.org/list.html?users@submarine.apache.org)
  for usage questions, help, and announcements.
- [Dev](https://lists.apache.org/list.html?dev@submarine.apache.org) : [subscribe](mailto:dev-subscribe@submarine.apache.org), [unsubscribe](mailto:dev-unsubscribe@submarine.apache.org), [archives](https://lists.apache.org/list.html?dev@submarine.apache.org)
  for people wanting to contribute to the project.
- [Commits](https://lists.apache.org/list.html?commits@submarine.apache.org) : [subscribe](mailto:commits-subscribe@submarine.apache.org), [unsubscribe](mailto:commits-unsubscribe@submarine.apache.org), [archives](https://lists.apache.org/list.html?commits@submarine.apache.org)
  for commit messages and patches.

Take subscribe Dev as an example, you should send an email to dev-subscribe@submarine.apache.org.

Usually, this happens when you just click the "subscribe" link. If this does not work, simply copy the address and paste it into the "To:" field of a new message.

After that, you will get an email from dev-help@submarine.apache.org, follow the directives of the mail to reply, then you will subscribe dev@submarine.apache.org successfully.

## License

Submarine source code is under the Apache 2.0 license. See the [LICENSE](https://github.com/apache/submarine/blob/master/LICENSE) file for details.

==> submarine-dist-0.7.0-src.tar.gz: submarine-dist-0.7.0-src/website/docs/community/README.md <==
---
title: Apache Submarine Community
---

<!--
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

Welcome to the Apache Submarine Community! The main objective is to help members of the Submarine community who share similar interests to learn from and collaborate with each other.

Your journey of becoming a contributor and committer starts from here: improving docs, improving code, giving talks, organizing meetups, etc.

## Communicating

You can reach out to the community members via any one of the following ways:

- Slack Developer: [https://join.slack.com/t/the-asf/shared_invite/zt-vlfbf7ch-HkbNHiU_uDlcH_RvaHv9gQ](https://join.slack.com/t/the-asf/shared_invite/zt-vlfbf7ch-HkbNHiU_uDlcH_RvaHv9gQ)
  :::info
  After clicking the link above, you would join the ASF slack workspace, where you could **search the submarine channel and join it.**
  :::
  ![slack_search_submarine](/img/slack_search_submarine.png)
  ![slack_join_submarine](/img/slack_join_submarine.png)
- Zoom: [https://cloudera.zoom.us/j/97264903288](https://cloudera.zoom.us/j/97264903288)

- Sync Up: [https://docs.google.com/document/d/16pUO3TP4SxSeLduG817GhVAjtiph9HYpRHo_JgduDvw/edit](https://docs.google.com/document/d/16pUO3TP4SxSeLduG817GhVAjtiph9HYpRHo_JgduDvw/edit)

## Your First Contribution

You can start by finding an existing issue with the [https://issues.apache.org/jira/projects/SUBMARINE/issues/SUBMARINE?filter=allopenissues](https://issues.apache.org/jira/projects/SUBMARINE/issues/SUBMARINE?filter=allopenissues) label. These issues are well suited for new contributors.

If a PR (Pull Request) submitted to the [Submarine Github](https://github.com/apache/submarine) projects by you is approved and merged, then you become a Submarine Contributor.

If you want to work on a new idea of relatively small scope:

1. Submit an issue describing your proposed change to the repo in question.

2. The repo owners will respond to your issue promptly.

3. Submit a [pull request of Submarine](https://github.com/apache/submarine) containing a tested change.

Contributions are welcomed and greatly appreciated. See [CONTRIBUTING](contributing.md) for details on submitting patches and the contribution workflow.

## How Do I Become a Committer?

First of all, you need to get involved and be a Contributor.

Based on your track-record as a contributor, Per Apache code, PMCs vote on committership, may invite you to be a committer (after we've called a vote). When that happens, if you accept, the following process kicks into place...

Note that becoming a committer is not just about submitting some patches; it‘s also about helping out on the development and user, helping with documentation and the issues.

See [How to become an Apache Submarine Committer and PMC](HowToBecomeCommitter.md) for more details.

## How to commit

See [How to commit](HowToCommit.md) for helper doc for Submarine committers.

## Communication

Communication within the Submarine community abides by [Apache’s Code of Conduct](https://www.apache.org/foundation/policies/conduct.html).

## Mailing lists

Get help using Apache Submarine or contribute to the project on our mailing lists:

- [Users](https://lists.apache.org/list.html?users@submarine.apache.org) : [subscribe](mailto:users-subscribe@submarine.apache.org), [unsubscribe](mailto:users-unsubscribe@submarine.apache.org), [archives](https://lists.apache.org/list.html?users@submarine.apache.org)
  for usage questions, help, and announcements.
- [Dev](https://lists.apache.org/list.html?dev@submarine.apache.org) : [subscribe](mailto:dev-subscribe@submarine.apache.org), [unsubscribe](mailto:dev-unsubscribe@submarine.apache.org), [archives](https://lists.apache.org/list.html?dev@submarine.apache.org)
  for people wanting to contribute to the project.
- [Commits](https://lists.apache.org/list.html?commits@submarine.apache.org) : [subscribe](mailto:commits-subscribe@submarine.apache.org), [unsubscribe](mailto:commits-unsubscribe@submarine.apache.org), [archives](https://lists.apache.org/list.html?commits@submarine.apache.org)
  for commit messages and patches.

Take subscribe Dev as an example, you should send an email to dev-subscribe@submarine.apache.org.

Usually, this happens when you just click the "subscribe" link. If this does not work, simply copy the address and paste it into the "To:" field of a new message.

After that, you will get an email from dev-help@submarine.apache.org, follow the directives of the mail to reply, then you will subscribe dev@submarine.apache.org successfully.

## License

Submarine source code is under the Apache 2.0 license. See the [LICENSE](https://github.com/apache/submarine/blob/master/LICENSE) file for details.
